@@ -3,8 +3,8 @@ from terminal import green,bold
 from .. import const
 from ..util import it
 
-def all(region=None, osspath=None, locale=None, image=None, type=None):
-    if not region and not osspath and not locale and not image and not type:
+def all(region=None, osspath=None, locale=None, image=None, type=None, version=None,god=None):
+    if not region and not osspath and not locale and not image and not type and not version and not god:
         show_config()
     else:
         if region:
@@ -17,7 +17,10 @@ def all(region=None, osspath=None, locale=None, image=None, type=None):
             update_image(image)
         if type:
             update_type(type)
-
+        if version:
+            update_version(version)
+        if god:
+            update_god(god)
         print(green('done'))
 
 def update_region(region):
@@ -37,31 +40,39 @@ def update_region(region):
 
 
 def update_osspath(osspath):
-    m = config.getConfigs(config.COMMON)
+    if osspath in ['', 'null', 'None', 'false', 'False']:
+        # remove
+        config.removeConfig(config.COMMON, 'osspath')
+    else:
+        m = config.getConfigs(config.COMMON)
 
-    if not osspath.endswith('/'):
-        osspath += '/'
-    m['osspath'] = osspath
+        if not osspath.endswith('/'):
+            osspath += '/'
+        m['osspath'] = osspath
 
-    try:
-        oss_client.check_client(m)
-        config.setConfigs(config.COMMON, m)
+        try:
+            oss_client.check_client(m)
+            config.setConfigs(config.COMMON, m)
 
-    except Exception as e:
-        raise Exception('Invalid osspath %s' % (osspath)) if m.get('osspath') else e
+        except Exception as e:
+            raise Exception('Invalid osspath %s' % (osspath)) if m.get('osspath') else e
 
 
 def update_locale(locale):
-    m = config.getConfigs(config.COMMON)
-    if locale not in const.LOCALE_SUPPORTED:
-        raise Exception('Unsupported locale')
+    if locale in ['', 'null', 'None', 'false', 'False']:
+        # remove
+        config.removeConfig(config.COMMON, 'locale')
+    else:
+        m = config.getConfigs(config.COMMON)
+        if locale not in const.LOCALE_SUPPORTED:
+            raise Exception('Unsupported locale')
 
-    m['locale'] = locale
-    config.setConfigs(config.COMMON, m)
+        m['locale'] = locale
+        config.setConfigs(config.COMMON, m)
 
 def update_image(image):
     image = image.strip()
-    if image == '':
+    if image in ['','null','None','false','False']:
         # remove
         config.removeConfig(config.COMMON, 'defaultimage')
     else:
@@ -71,7 +82,7 @@ def update_image(image):
 
 def update_type(type):
     type = type.strip()
-    if type == '':
+    if type in ['','null','None','false','False']:
         # remove
         config.removeConfig(config.COMMON, 'defaulttype')
     else:
@@ -88,9 +99,36 @@ def update_type(type):
         else:
             raise Exception('Invalid instanceType: %s' % type)
 
+def update_version(version):
+    m = config.getConfigs(config.COMMON)
+
+    version = version.strip()
+    if version in ['', 'null', 'None', 'false', 'False']:
+        config.removeConfig(config.COMMON, 'version')
+    else:
+        m['version'] = version
+        try:
+            client.check_client(m)
+            config.setConfigs(config.COMMON, m)
+        except Exception as e:
+            raise Exception('Invalid version %s' % version)
+
+
+
+def update_god(god):
+    m = config.getConfigs(config.COMMON)
+    god = god.strip()
+    if god not in ['', 'null', 'None', 'false', 'False']:
+        m['god'] = '1'
+        config.setConfigs(config.COMMON, m)
+    else:
+        config.removeConfig(config.COMMON, 'god')
+
+
 def show_config():
     try:
-        arr = ['region','accesskeyid','accesskeysecret','osspath','locale', 'defaultimage','defaulttype']
+        arr = ['region','accesskeyid','accesskeysecret','version','osspath','locale', 'defaultimage','defaulttype','god',
+               'oss_region','oss_id','oss_key']
         opt = config.getConfigs(config.COMMON, arr)
         if not opt:
             raise Exception('error')
@@ -98,9 +136,10 @@ def show_config():
             if opt.get(k):
                 v = hide_key(opt[k]) if k=='accesskeysecret' else opt[k]
                 print('%s: %s' %(bold(k), green(v)))
-    except:
+    except Exception as e:
         raise Exception('You need to login first')
 
+
 def hide_key(s):
     if len(s) > 6:
         return "%s******%s" % (s[:3],s[-3:])
