@@ -7,7 +7,7 @@ CMD = 'bcs'
 
 LOCALE_SUPPORTED = ['en', 'zh', 'zh_CN']
 
-VERSION = '1.2.7'
+VERSION = '1.2.8'
 
 
 IT = {
@@ -24,13 +24,31 @@ IT = {
             {'cpu': 16, 'memory': 64, 'name': 'ecs.c2.xlarge'}
         ],
         'default': 'ecs.s3.large'
+    },
+    'cn-shenzhen': {
+        'data': [
+            {'cpu': 4, 'memory': 8, 'name':'bcs.a2.large'},
+            {'cpu': 8, 'memory': 16, 'name': 'bcs.a2.xlarge'},
+            {'cpu': 16, 'memory': 32, 'name':'bcs.a2.3xlarge'},
+            # {'cpu': 16, 'memory': 32, 'name': 'bcs.b2.3xlarge'},
+            # {'cpu': 8, 'memory': 32, 'name':'bcs.b4.xlarge'},
+            # {'cpu': 16, 'memory': 64, 'name': 'bcs.b4.3xlarge'},
+            # {'cpu': 24, 'memory': 96, 'name': 'bcs.b4.5xlarge'},
+        ],
+        'default': 'bcs.a2.large'
     }
 }
 
+
+
 IMG = {
     'cn-qingdao': {
         'data': [],
-        'default': 'm-282q1y6ld'
+        'default': 'm-28ga7wbnb'
+    },
+    'cn-shenzhen': {
+        'data': [],
+        'default': 'm-94kl8am5i'
     }
 }
 
