@@ -1,10 +1,17 @@
 
 from __future__ import print_function
-from drawille import Turtle
-
+from terminal import white
 
 def draw(deps, matric=None):
 
+    # window has not __curses module
+    try:
+        from drawille import Turtle
+
+    except:
+        print(white('DAG view in this system is unsupported.'))
+        return
+
     if matric==None:
         matric = sortIndex(deps)
 
